@@ -1,12 +1,9 @@
 import typing
 
 
-class GitRef(typing.TypedDict):
-    ref: str
-
-
-class HeadRef(typing.TypedDict):
+class PullRequestRef(typing.TypedDict):
     sha: str
+    ref: str
 
 
 class PullRequest(typing.TypedDict):
@@ -14,10 +11,13 @@ class PullRequest(typing.TypedDict):
     number: str
     title: str
     body: str | None
-    head: HeadRef
+    base: PullRequestRef
+    head: PullRequestRef
     state: str
     draft: bool
     node_id: str
+    merged_at: str | None
+    merge_commit_sha: str | None
 
 
 class Comment(typing.TypedDict):
